/* -*- c++ -*- */
/*
 * Copyright 2002 Free Software Foundation, Inc.
 * 
 * This file is part of GNU Radio
 * 
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _QA_GENERAL_H_
#define _QA_GENERAL_H_

#include <gruel/attributes.h>
#include <cppunit/TestSuite.h>

//! collect all the tests for the gr directory

class __GR_ATTR_EXPORT qa_general {
 public:
  //! return suite of tests for all of gr directory
  static CppUnit::TestSuite *suite ();
};


#endif /* _QA_GENERAL_H_ */
